Crate rsomics_help

Crate rsomics_help 

Unified command-line interaction and presentation for rsomics products. Products define one Clap command tree and parse it through parse.

Functions

command
Builds the product command tree with the family UX applied recursively.
parse
Parses process arguments, exiting with Clap’s standard help and error codes.
try_parse
Parses process arguments without exiting.
try_parse_from
Parses an explicit argument iterator without exiting.